@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION @EXPORT @EXPORT_OK @ISA $CurrentPackage @IncludeLibs $ScanFileRE );
 
-$VERSION   = '1.31';
+$VERSION   = '1.32';
 @EXPORT    = qw( scan_deps scan_deps_runtime );
 @EXPORT_OK = qw( scan_line scan_chunk add_deps scan_deps_runtime path_to_inc_name );
 
@@ -424,6 +424,12 @@ my %Preload = (
     },
     'Module/Implementation.pm'          => \&_warn_of_runtime_loader,
     'Module/Runtime.pm'                 => \&_warn_of_runtime_loader,
+    'Mojo/Util.pm'                      => sub {        # html_entities.txt
+        map { $_->{name} } _glob_in_inc('Mojo/resources', 0)
+    },
+    'Mojo/IOLoop/TLS.pm'                => sub {        # server.{crt,key}
+        map { $_->{name} } _glob_in_inc('Mojo/IOLoop/resources', 0)
+    },
     'Net/DNS/Resolver.pm'               => 'sub',
     'Net/DNS/RR.pm'                     => 'sub',
     'Net/FTP.pm'                        => 'sub',
@@ -491,7 +497,7 @@ my %Preload = (
     },
     'SVN/Core.pm'                       => sub {
         _glob_in_inc('SVN', 1),
-        map $_->{name}, _glob_in_inc('auto/SVN', 0),    # *.so, *.bs files
+        map { $_->{name} } _glob_in_inc('auto/SVN', 0),    # *.so, *.bs files
     },
     'Template.pm'                       => 'sub',
     'Term/ReadLine.pm'                  => 'sub',
@@ -535,11 +541,8 @@ my %Preload = (
     'YAML/Any.pm'                       => sub {
         # try to figure out what YAML::Any would have used
         my $impl = eval "use YAML::Any; YAML::Any->implementation;";
-        unless ($@)
-        {
-            $impl =~ s!::!/!g;
-            return "$impl.pm";
-        }
+        return _mod2pm($impl) unless $@;
+
         _glob_in_inc('YAML', 1);        # fallback
     },
 );
@@ -597,8 +600,10 @@ sub scan_deps {
     }
     my ($type, $path);
     foreach my $input_file (@{$args{files}}) {
-        if ($input_file !~ $ScanFileRE) {
-            warn "Skipping input file $input_file because it matches \$Module::ScanDeps::ScanFileRE\n" if $args{warn_missing};
+        if ($input_file !~ $ScanFileRE)  {
+            warn "Skipping input file $input_file"
+                 . " because it doesn't match \$Module::ScanDeps::ScanFileRE\n"
+                    if $args{warn_missing};
             next;
         }
 
@@ -809,22 +814,20 @@ sub scan_deps_runtime {
 sub scan_file{
     my $file = shift;
     my %found;
-    my $FH;
-    open $FH, $file or die "Cannot open $file: $!";
+    open my $fh, $file or die "Cannot open $file: $!";
 
     $SeenTk = 0;
     # Line-by-line scanning
   LINE:
-    while (<$FH>) {
-        chomp(my $line = $_);
+    while (my $line = <$fh>) {
+        chomp($line);
         foreach my $pm (scan_line($line)) {
             last LINE if $pm eq '__END__';
 
             if ($pm eq '__POD__') {
-                while (<$FH>) {
-                    last if (/^=cut/);
+                while ($line = <$fh>) {
+                    next LINE if $line =~ /^=cut/;
                 }
-                next LINE;
             }
 
             # Skip Tk hits from Term::ReadLine and Tcl::Tk
@@ -838,7 +841,7 @@ sub scan_file{
             $found{$pm}++;
         }
     }
-    close $FH or die "Cannot close $file: $!";
+    close $fh or die "Cannot close $file: $!";
     return keys %found;
 }
 
@@ -850,14 +853,13 @@ sub scan_line {
     return '__POD__' if $line =~ /^=\w/;
 
     $line =~ s/\s*#.*$//;
-    $line =~ s/[\\\/]+/\//g;
 
   CHUNK:
     foreach (split(/;/, $line)) {
         s/^\s*//;
-        #  handle single line blocks like 'do { package foo; use xx; }'
-        s/^(?:do\s*)?\{\s*//;
-        s/\}$//;
+        s/^\w+:\s*//;           # remove LABEL:
+        s/^(?:do\s*)?\{\s*//;   # handle single line blocks like 'do { package foo; use xx; }'
+        s/\s*\}$//;
 
         if (/^package\s+(\w+)/) {
             $CurrentPackage = $1;
@@ -868,10 +870,10 @@ sub scan_line {
         if (/^(?:use|require)\s+v?(\d[\d\._]*)/) {
           # include feature.pm if we have 5.9.5 or better
           if (version->new($1) >= version->new("5.9.5")) {
-              # seems to catch 5.9, too (but not 5.9.4)
+            # seems to catch 5.9, too (but not 5.9.4)
             $found{"feature.pm"}++;
-            next CHUNK;
           }
+          next CHUNK;
         }
 
         if (my ($pragma, $args) = /^use \s+ (autouse|if) \s+ (.+)/x)
@@ -904,9 +906,8 @@ sub scan_line {
                 # punt if there was a syntax error
                 return if $@ or !defined $module;
             };
-            $module =~ s{::}{/}g;
-            $found{"$pragma.pm"}++;
-            $found{"$module.pm"}++;
+            $found{_mod2pm($pragma)}++;
+            $found{_mod2pm($module)}++;
             next CHUNK;
         }
 
@@ -932,79 +933,89 @@ sub scan_line {
     return sort keys %found;
 }
 
-# short helper for scan_chunk
+# short helpers for scan_chunk
 my %LoaderRegexp; # cache
-sub _build_loader_regexp {
-    my $loaders = shift;
-    my $prefix = (@_ && $_[0]) ? $_[0].'::' : '';
 
-    my $loader = join '|', map quotemeta($_), split /\s+/, $loaders;
-    my $regexp = qr/^\s* use \s+ ($loader)(?!\:) \b \s* (.*)/sx;
-    # WARNING: This doesn't take the prefix into account
-    $LoaderRegexp{$loaders} = $regexp;
-    return $regexp
+sub _check_loader {
+    my ($chunk, $loaders, $prefix) = @_;
+    $LoaderRegexp{$loaders} ||= _build_loader_regexp($loaders);
+
+    if (my ($loader, $loadee) = $chunk =~ $LoaderRegexp{$loaders}) {
+        return _extract_loader_dependency($loader, $loadee, $prefix);
+    }
+    return;
 }
 
-# short helper for scan_chunk
-sub _extract_loader_dependency {
-    my $loader = shift;
-    my $loadee = shift;
-    my $prefix = (@_ && $_[0]) ? $_[0].'::' : '';
+sub _build_loader_regexp {
+    my ($loaders) = @_;
+    my $alt = join('|', map { quotemeta($_) }
+                            split(/\s+/, $loaders));
+    return qr/^\s* use \s+ ($alt)(?!\:) \b \s* (.*)/sx;
+}
 
-    my $loader_file = $loader;
-    $loader_file =~ s/::/\//;
-    $loader_file .= ".pm";
+sub _extract_loader_dependency {
+    my ($loader, $loadee, $prefix) = @_;
+    $prefix = $prefix ? "${prefix}::" : "";
 
     return [
-        $loader_file,
-        map { my $mod="$prefix$_"; $mod =~ s{::}{/}g; "$mod.pm" }
-        grep { length and !/^q[qw]?$/ and !/-/ }
-        split /[^\w:-]+/, $loadee
+        _mod2pm($loader),
+        map { _mod2pm("$prefix$_") }
+            grep { length and !/^q[qw]?$/ and !/-/ }
+                 split /[^\w:-]+/, $loadee
         #should skip any module name that contains '-', not split it in two
     ];
 }
 
+sub _mod2pm {
+    my $mod = shift;
+    $mod =~ s!::!/!g;
+    return "$mod.pm";
+}
+
 sub scan_chunk {
     my $chunk = shift;
 
     # Module name extraction heuristics {{{
     my $module = eval {
-        $_ = $chunk;
+        local $_ = $chunk;
         s/^\s*//;
-        #  handle single line blocks like 'do { package foo; use xx; }'
-        s/^(?:do\s*)?\{\s*//;
-        s/\}\s*$//;
+
+        # "if", "while" etc: analyze the expression
+        s/^(?:if|elsif|unless|while|until) \s* \( \s*//x;
+
+        # "eval" with a block: analyze the block
+        s/^eval \s* \{ \s*//x;
+
+        # "eval" with an expression that's a string literal:
+        # analyze the string
+        s/^eval \s+ (?:['"]|qq?\s*\W) \s*//x;
 
         # TODO: There's many more of these "loader" type modules on CPAN!
         # scan for the typical module-loader modules
-        my $loaders = "asa base parent prefork POE encoding maybe only::matching Mojo::Base";
         # grab pre-calculated regexp or re-build it (and cache it)
-        my $loader_regexp = $LoaderRegexp{$loaders} || _build_loader_regexp($loaders);
-        if ($_ =~ $loader_regexp) { # $1 == loader, $2 == loadee
-          my $retval = _extract_loader_dependency($1, $2);
-          return $retval if $retval;
+        if (my $mods = _check_loader(
+            $_, "asa base parent prefork POE encoding maybe only::matching Mojo::Base")) {
+            return $mods;
+        }
+        if (my $mods = _check_loader(
+            $_, "Catalyst", "Catalyst::Plugin")) {
+            return $mods;
         }
 
-        $loader_regexp = $LoaderRegexp{"Catalyst"} || _build_loader_regexp("Catalyst", "Catalyst::Plugin");
-        if ($_ =~ $loader_regexp) { # $1 == loader, $2 == loadee
-          my $retval = _extract_loader_dependency($1, $2, "Catalyst::Plugin");
-          return $retval if $retval;
+        if (/^use \s+ Class::Autouse \b \s* (.*)/sx
+            or /^Class::Autouse \s* -> \s* autouse \s* (.*)/sx) {
+          return [ 'Class/Autouse.pm',
+                   map { _mod2pm($_) }
+                     grep { length and !/^:|^q[qw]?$/ }
+                       split(/[^\w:]+/, $1) ];
         }
 
-        return [ 'Class/Autouse.pm',
-            map { s{::}{/}g; "$_.pm" }
-              grep { length and !/^:|^q[qw]?$/ } split(/[^\w:]+/, $1) ]
-          if /^use \s+ Class::Autouse \b \s* (.*)/sx
-              or /^Class::Autouse \s* -> \s* autouse \s* (.*)/sx;
+        return _mod2pm($1) if /^(?:use|no) \s+ ([\w:]+)/x; # bareword
 
-        return $1 if /^(?:use|no|require) \s+ ([\w:\.\-\\\/\"\']+)/x;
-        return $1
-          if /^(?:use|no|require) \s+ \( \s* ([\w:\.\-\\\/\"\']+) \s* \)/x;
-
-        if (   s/^eval\s+\"([^\"]+)\"/$1/
-            or s/^eval\s*\(\s*\"([^\"]+)\"\s*\)/$1/)
-        {
-            return $1 if /^\s* (?:use|no|require) \s+ ([\w:\.\-\\\/\"\']*)/x;
+        if (s/^(require|do) [\s(]+//x) {
+            return _mod2pm($1)                          # bareword ("require" only)
+                if $1 eq "require" && /^([\w:]+)/;
+            return $_;                                  # maybe string literal?
         }
 
         if (/(<[^>]*[^\$\w>][^>]*>)/) {
@@ -1032,8 +1043,6 @@ sub scan_chunk {
             return [qw( Encode.pm ), _find_encoding($1)];
         }
 
-        return $1 if /\b do \s+ ([\w:\.\-\\\/\"\']*)/x;
-
         if ($SeenTk) {
             my @modules;
             while (/->\s*([A-Z]\w+)/g) {
@@ -1055,10 +1064,10 @@ sub scan_chunk {
         }
 
         # Module::Runtime
-        return $1 if /\b(?:require_module|use_module|use_package_optimistically) \s* \( \s* ([\w:"']+)/x;
+        return $_ if s/^(?:require_module|use_module|use_package_optimistically) \s* \( \s*//x;
 
         # Test::More
-        return $1 if /\b(?:require_ok|use_ok) \s* \( \s* ([\w:"']+)/x;
+        return $_ if s/^(?:require_ok|use_ok) \s* \( \s*//x;
 
         return;
     };
@@ -1068,10 +1077,15 @@ sub scan_chunk {
     return unless defined($module);
     return wantarray ? @$module : $module->[0] if ref($module);
 
-    $module =~ s/^['"]//;
-    return unless $module =~ /^\w/;
+    # extract contents from string literals
+    if ($module =~ /^(['"]) (.*?) \1/x) {
+        $module = $2;
+    }
+    elsif ($module =~ s/^qq? \s* (\W)//x) {
+        (my $closing = $1) =~  tr:([{<:)]}>:;
+        $module =~ s/\Q$closing\E.*//;
+    }
 
-    $module =~ s/\W+$//;
     $module =~ s/::/\//g;
     return if $module =~ /^(?:[\d\._]+|'.*[^']|".*[^"])$/;
 
@@ -1084,8 +1098,7 @@ sub _find_encoding {
     return unless $] >= 5.008 and eval { require Encode; %Encode::ExtModule };
 
     my $mod = eval { $Encode::ExtModule{ Encode::find_encoding($enc)->name } } or return;
-    $mod =~ s{::}{/}g;
-    return "$mod.pm";
+    return _mod2pm($mod);
 }
 
 sub _add_info {
@@ -1213,25 +1226,28 @@ sub _find_in_inc {
 }
 
 sub _glob_in_inc {
-    my $subdir  = shift;
-    my $pm_only = shift;
-    my @files;
+    my ($subdir, $pm_only) = @_;
 
     require File::Find;
 
     $subdir =~ s/\$CurrentPackage/$CurrentPackage/;
 
+    my @files;
     foreach my $inc (grep !/\bBSDPAN\b/, @INC, @IncludeLibs) {
         my $dir = "$inc/$subdir";
         next unless -d $dir;
+
+        # canonicalize $inc as newer versions of File::Find return
+        # a canonicalized $File::Find::name
+        (my $canon = $inc) =~ s|\\|\/|g;
         File::Find::find(
             sub {
-                return unless -f;
+                return unless -f $_;
                 return if $pm_only and !/\.p[mh]$/i;
-                (my $name = $File::Find::name) =~ s!^\Q$inc\E/!!;
-                push @files, $pm_only
-                  ? $name
-                  : { file => $File::Find::name, name => $name };
+                (my $name = $File::Find::name) =~ s|\\|\/|g;
+                $name =~ s|^\Q$canon\E/||;
+                push @files, $pm_only ? $name
+                                      : { file => $File::Find::name, name => $name };
             },
             $dir
         );
@@ -1245,12 +1261,11 @@ sub _glob_in_inc {
 # NOTE: File::Find has no public notion of the depth of the traversal
 # in its "wanted" callback, so it's not helpful
 sub _glob_in_inc_1 {
-    my $subdir  = shift;
-    my $pm_only = shift;
-    my @files;
+    my ($subdir, $pm_only) = @_;
 
     $subdir =~ s/\$CurrentPackage/$CurrentPackage/;
 
+    my @files;
     foreach my $inc (grep !/\bBSDPAN\b/, @INC, @IncludeLibs) {
         my $dir = "$inc/$subdir";
         next unless -d $dir;
@@ -1259,9 +1274,8 @@ sub _glob_in_inc_1 {
         my @names = map { "$subdir/$_" } grep { -f "$dir/$_" } readdir $dh;
         closedir $dh;
 
-        push @files, $pm_only
-            ? ( grep { /\.p[mh]$/i } @names )
-            : ( map { { file => "$inc/$_", name => $_ } } @names );
+        push @files, $pm_only ? ( grep { /\.p[mh]$/i } @names )
+                              : ( map { { file => "$inc/$_", name => $_ } } @names );
     }
 
     return @files;
@@ -1295,8 +1309,7 @@ sub set_options {
     my $self = shift;
     my %args = @_;
     foreach my $module (@{ $args{add_modules} }) {
-        $module =~ s/::/\//g;
-        $module .= '.pm' unless $module =~ /\.p[mh]$/i;
+        $module = _mod2pm($module) unless $module =~ /\.p[mh]$/i;
         my $file = _find_in_inc($module)
           or _warn_of_missing_module($module, $args{warn_missing}), next;
         $self->{files}{$module} = $file;
@@ -1534,8 +1547,6 @@ sub _info2rv {
 
     foreach my $key (keys %{ $info->{'%INC'} }) {
         (my $path = $info->{'%INC'}{$key}) =~ s:\\:/:g;
-        $key =~ s:\\:/:g;
-        $key =~ s/$strip_inc_prefix// if File::Spec->file_name_is_absolute($key);
 
         $rv->{$key} = {
             'used_by' => [],
